@@ -4,7 +4,7 @@
 /* Library :  Dynamic Array Library (dal)                                  */
 /* File    :  bgeot_smatrix.h : a example of non optimized sparse matrix   */
 /*                              type.                                      */
-/*            Please use a specialized matrix modulus instead.             */
+/*            Please use a specialized matrix package instead.             */
 /*     									   */
 /*                                                                         */
 /* Date : February 01, 1998.                                               */
@@ -67,8 +67,6 @@ namespace bgeot
     };
     
     typedef dal::dynamic_tree_sorted<elt_m, _elt_m_comp, 3> _line_m;
-
-  protected:
     
     size_type nbc, nbl;      /* Number of columns and lines.           	*/
     std::vector<_line_m> li; /* array of lines.                         */
@@ -77,8 +75,6 @@ namespace bgeot
     
     void init(size_type l, size_type c) { nbl = l; nbc = c; li.resize(l); }
     
-  public:
-    
     /* read and write operations.                                       */
     
     inline _line_m & operator[](size_type i) { return li[i]; }
@@ -116,8 +112,6 @@ namespace bgeot
 			 const smatrix<R>& m2, size_type j);
     template<class R> friend R partial_ll_product(const smatrix<R>& m1, size_type i,
 				 const smatrix<R>& m2, size_type j, size_type k);
-    template<class R> friend R lv_product(const smatrix<R> &m1, size_type i,
-				   const typename smatrix<R>::vector_type &v);
 
     void l_mul(size_type l, T x);
 
@@ -196,7 +190,7 @@ namespace bgeot
   
   template<class T> T lc_product(const smatrix<T>& m1, size_type i,
 				 const smatrix<T>& m2, size_type j) {
-    smatrix<T>::_line_m *t = &(m1.li[i]); smatrix<T>::elt_m *e;
+    typename smatrix<T>::_line_m *t = &(m1.li[i]); typename smatrix<T>::elt_m *e;
     T res = T(0);  
     for (size_type k = t->card()-1; k != size_type(-1); k--)
       { e = &((*t)[k]); res += e->val*m2.r(e->rang, j); }
@@ -206,7 +200,7 @@ namespace bgeot
   template<class T> T partial_lc_product(const smatrix<T>& m1, size_type i,
 					 const smatrix<T>& m2, size_type j, size_type k)
   { /* Somme pour l <= k de m1(i,l) * m2(l,j).		*/
-    smatrix<T>::_line_m *t = &(m1.li[i]); smatrix<T>::elt_m *e;
+    typename smatrix<T>::_line_m *t = &(m1.li[i]); typename smatrix<T>::elt_m *e;
     T res = 0;
     for (size_type l = t->card()-1; l != size_type(-1); l--)
       { e =&((*t)[l]); if (e->rang <= k) res += e->val * m2.r(e->rang, j);}
@@ -216,7 +210,7 @@ namespace bgeot
   template<class T> T ll_product(const smatrix<T>& m1, size_type i,
 				 const smatrix<T>& m2, size_type j)
   { /* Produit de la ligne i de m1 par la ligne j de m2.	*/
-    smatrix<T>::_line_m *t = &(m1.li[i]); smatrix<T>::elt_m *e;
+    typename smatrix<T>::_line_m *t = &(m1.li[i]); typename smatrix<T>::elt_m *e;
     T res = 0;
     for (size_type k = t->card()-1; k != size_type(-1); k--)
       {  e = &((*t)[k]); res += e->val * m2.r(j, e->rang); }
