@@ -70,29 +70,16 @@
 #include <string>
 #include <strstream>
 
-/* ********************************************************************** */
-/*	STD Needed.                     			          */
-/* ********************************************************************** */
-/* Macro for the supplementary std needed by g++ v3.00 and not wanted by  */
-/* cxx for instance.                                                      */ 
-/* ********************************************************************** */
-
-// #if defined(__GNUC__) || (defined(__sgi) && defined(_STANDARD_C_PLUS_PLUS))
-#define STD_NEEDED std::
 using std::endl;
 using std::cout;
 using std::cerr;
 using std::ends;
-// #else
-//   #define STD_NEEDED
-// #endif
-
+using std::cin;
 
 /* ********************************************************************** */
 /*	S.T.L. Reverse iterator definition.				  */
 /* ********************************************************************** */
 
-
 #if defined(_MSC_VER) && !defined(__MWERKS__)
 #define _GETFEM_MSVCPP_ _MSC_VER
 #endif
@@ -192,19 +179,19 @@ namespace dal
 
 
 #ifndef M_PI   
-# define	M_E		2.7182818284590452354   /* e          */
-# define	M_LOG2E		1.4426950408889634074   /* 1/ln(2)    */
-# define	M_LOG10E	0.43429448190325182765  /* 1/ln(10)   */
-# define	M_LN2		0.69314718055994530942  /* ln(2)      */
-# define	M_LN10		2.30258509299404568402  /* ln(10)     */
-# define	M_PI		3.14159265358979323846  /* pi         */
-# define	M_PI_2		1.57079632679489661923  /* pi/2       */
-# define	M_PI_4		0.78539816339744830962  /* pi/4       */
-# define	M_1_PI		0.31830988618379067154  /* 1/pi       */
-# define	M_2_PI		0.63661977236758134308  /* 2/pi       */
-# define	M_2_SQRTPI	1.12837916709551257390  /* 2/sqrt(pi) */
-# define	M_SQRT2		1.41421356237309504880  /* sqrt(2)    */
-# define	M_SQRT1_2	0.70710678118654752440  /* sqrt(2)/2  */
+# define	M_E		2.7182818284590452354       /* e          */
+# define	M_LOG2E		1.4426950408889634074       /* 1/ln(2)    */
+# define	M_LOG10E	0.43429448190325182765      /* 1/ln(10)   */
+# define	M_LN2		0.69314718055994530942      /* ln(2)      */
+# define	M_LN10		2.30258509299404568402      /* ln(10)     */
+# define	M_PI		3.14159265358979323846      /* pi         */
+# define	M_PI_2		1.57079632679489661923      /* pi/2       */
+# define	M_PI_4		0.78539816339744830962      /* pi/4       */
+# define	M_1_PI		0.31830988618379067154      /* 1/pi       */
+# define	M_2_PI		0.63661977236758134308      /* 2/pi       */
+# define	M_2_SQRTPI	1.12837916709551257390      /* 2/sqrt(pi) */
+# define	M_SQRT2		1.41421356237309504880      /* sqrt(2)    */
+# define	M_SQRT1_2	0.70710678118654752440      /* sqrt(2)/2  */
 
 # define M_PIl       3.1415926535897932384626433832795029L  /* pi         */
 # define M_PI_2l     1.5707963267948966192313216916397514L  /* pi/2       */
@@ -294,6 +281,12 @@ typedef unsigned char uint8_type;
       { }
   };
 
+  class file_not_found_error : public std::logic_error {
+  public:
+    file_not_found_error(const std::string& what_arg)
+      : std::logic_error (what_arg) { }
+  };
+
   class internal_error : public std::logic_error {
   public:
     internal_error(const std::string& what_arg): std::logic_error (what_arg)
@@ -347,7 +340,7 @@ typedef unsigned char uint8_type;
 
   #define DAL_THROW(type, thestr) { \
     std::strstream msg; \
-    msg << "in "__FILE__ << ", line " << __LINE__ << " : " << thestr << ends; \
+    msg << "in "__FILE__ << ", line " << __LINE__ << ": \n" << thestr << ends;\
     throw (type)(msg.str()); \
   }
 
