@@ -50,17 +50,16 @@ namespace getfem
 		       const VECT &U, dim_type P, short_type K)
   { 
     dim_type N = mf.linked_mesh().dim();
-    STD_NEEDED ofstream o((filename + char(0)).data());
-    if (o == NULL)
-      throw internal_error("save_solution : impossible to open file");
+    std::ofstream o((filename + char(0)).data());
+    if (!o) DAL_THROW(internal_error, "impossible to open file");
     dal::bit_vector nn = mf.convex_index();
     size_type cv;
     base_node pt1(N), pt2, pt3(P), val(1);
     base_matrix G;
     base_vector coeff;
 
-    o << "% GETFEM++ DATA FILE\nDATA BY ELEMENT\nN = " << int(N) << "\nP = ";
-    o << int(P) << "\nK = " << K << endl;
+    o << "% GETFEM++ DATA FILE\nBEGIN DATA ELEMENT\nN = " << int(N)
+      << "\nP = " << int(P) << "\nK = " << K << endl << endl;
     o.precision(14);
     for (cv << nn; cv != ST_NIL; cv << nn)
     {
@@ -72,8 +71,10 @@ namespace getfem
       size_type nbpt = pgt->nb_points();
       coeff.resize(nbd1);
 
+      o << "DIM = " << pgt->dim() << endl;
+
       if (pf1->target_dim() != 1 || !(pf1->is_equivalent()))
-	throw to_be_done_error("save_solution : to be done ... ");
+	DAL_THROW(to_be_done_error, "to be done ... ");
       
       for (size_type i = 0; i < nbd2; ++i)
       {
@@ -106,9 +107,140 @@ namespace getfem
       }
       o << endl;
     }
+    o << "END DATA ELEMENT" << endl;
     o.close();
   }
 
+  template<class VECT>
+    void load_solution(const std::string &fi, getfem_mesh &mesh,
+		       mesh_fem &mef, VECT &U, dim_type &P, short_type &K) {
+    std::ifstream ist((fi + char(0)).data());
+    size_type token, DIM, Np, N;
+    char tmp[100], c;
+    bool error = false, began = false;
+    dal::dynamic_array<base_node> ptab;
+    dal::dynamic_array<scalar_type> vtab;
+    size_type nbvtab = 0;
+    
+    if (!ist) DAL_THROW(file_not_found_error, "File " << fi << " not found");
+
+    N = 1; P = 1; K = 1; DIM = 1; // Default parameters
+    
+    if (!(ftool::read_untill(ist, "BEGIN DATA ELEMENT"))) error = true;
+
+    while (!error) {
+      if (ist.eof()) { error = true; break; }
+      ftool::get_token(ist, tmp, 99); token = 0;
+      if (!strcmp(tmp, "N")) token = 1;
+      if (!strcmp(tmp, "P")) token = 2;
+      if (!strcmp(tmp, "K")) token = 3;
+      if (!strcmp(tmp, "DIM")) token = 4;
+      if (!strcmp(tmp, "END")) break;
+      if (token) {
+	if (token >= 1 && token <= 2 && began)
+	  cerr << "WARNING : Ignoring principal dimensions redefinition"<<endl;
+	else {
+	  ftool::get_token(ist, tmp, 99);
+	  if (strcmp(tmp, "=")) error = true;
+	  ftool::get_token(ist, tmp, 99);
+	  int k = atoi(tmp); if (k < 0 || k > 254) error = true;
+	  // cout << "token " << token << " val = " << k << endl;
+	  switch (token) {
+	  case 1 : DIM = N = k; if (k == 0) error = true; break;
+	  case 2 : P = k; if (k == 0) error = true; break;
+	  case 3 : K = k; break;
+	  case 4 : DIM = k; break;
+	  }
+	}
+      }
+      else {
+	began = true;
+	// cout << "tmp =" << tmp << endl;
+	ist.putback(' ');
+	for(int k = strlen(tmp)-1; k >= 0; --k) ist.putback(tmp[k]);
+	size_type nbpt = 0;
+	// cout << "N = " << N << " P = " << int(P) << " K = "
+	//      << K << " DIM = " << DIM << endl;
+	while(nbpt < 1000) {
+	  if (ptab[nbpt].size() != N) ptab[nbpt].resize(N);
+	  for (int i = 0; i < N; ++i) ist >> (ptab[nbpt])[i];
+	  // cout << "Ptab[" << nbpt << "] = " << ptab[nbpt] << endl;
+	  for (int i = 0; i < P; ++i) ist >> vtab[nbvtab * P + i];
+	  nbpt++; nbvtab++;
+	  while(ist.get(c))
+	    { if (!(isspace(c)) || c == 10) { ist.putback(c); break; } }
+	  ist.get(c); if (c != 10 && !(ist.eof())) { error = true; break; }
+	  while(ist.get(c))
+	    { if (!(isspace(c)) || c == 10) { ist.putback(c); break; } }
+	  ist.get(c); if (c == 10 || ist.eof()) break; else ist.putback(c);
+	}
+	if (nbpt >= 1000) { error = true; break; }
+	if (nbpt == 0) break;
+
+	Np = 1; for (int i = 0; i < DIM; ++i) Np *= K + 1;
+	
+	if (nbpt == bgeot::alpha(DIM, K)) {
+	  std::vector<getfem::base_node> pnode(DIM+1);
+	  for (int i = 0; i <= DIM; ++i) 
+	    pnode[i] = ptab[bgeot::alpha(i, K) - 1];
+	  int i = mesh.add_simplex_by_points(DIM, pnode.begin());
+	  mef.set_finite_element(i, getfem::PK_fem(DIM, K),
+				 bgeot::simplex_poly_integration(DIM));
+	}
+	else if (nbpt == Np) {
+	  std::vector<getfem::base_node> pnode(1 << DIM);
+	  size_type j = 0;
+	  for (int i = 0; i <= (1 << DIM); ++i) {
+	    pnode[i] = ptab[j];
+	    size_type k = i + 1, l = K-1;
+	    while (!(k & 1)) { l *= K+1; k >>= 1; }
+	    j += l + 1;
+	  }
+	  j = mesh.add_parallelepiped_by_points(DIM, pnode.begin());
+	  mef.set_finite_element(j, getfem::QK_fem(DIM, K),
+				 bgeot::parallelepiped_poly_integration(DIM));
+	}
+	else if (nbpt == bgeot::alpha(DIM - 1, K) * bgeot::alpha(1, K)) {
+	  std::vector<getfem::base_node> pnode(2*DIM);
+	  for (int i = 0; i < DIM; ++i)
+	    pnode[i] = ptab[bgeot::alpha(i, K) - 1];
+	  for (int i = 0; i < DIM; ++i)
+	    pnode[i+DIM] = ptab[bgeot::alpha(i, K)-1 + bgeot::alpha(DIM-1, K)];
+	  int i = mesh.add_prism_by_points(DIM, pnode.begin());
+	  mef.set_finite_element(i, getfem::PK_prism_fem(DIM, K),
+				 bgeot::prism_poly_integration(DIM));
+	}
+	else 
+	  DAL_THROW(failure_error, "Unknown element in file " << fi);
+      }
+    }
+    
+    ist.close();
+    if (error) DAL_THROW(failure_error, "Format error in file " << fi);
+    
+    // Data repartition
+    
+    dal::bit_vector nn = mesh.convex_index();
+    U.resize(mef.nb_dof() * P);
+    std::fill(U.begin(), U.end(), 0.0);
+    std::vector<int> cp(mef.nb_dof());
+    std::fill(cp.begin(), cp.end(), 0);
+    size_type l = 0, i;
+    for (i << nn; i != size_type(-1); i << nn) {
+      size_type nbd = mef.nb_dof_of_element(i);
+      for (int j = 0; j < nbd; ++j, ++l) {
+	size_type dof = mef.ind_dof_of_element(i)[j];
+	for (int k = 0; k < P; ++k) U[dof*P +k] += vtab[l*P+k];
+	(cp[dof])++;
+      }
+    }
+    for (i = 0; i < mef.nb_dof(); ++i) {
+      if (cp[i] == 0) DAL_THROW(internal_error, "Internal error");
+      for (int k = 0; k < P; ++k) U[i*P +k] /= getfem::scalar_type(cp[i]);
+    }
+    
+  }
+
   /* ********************************************************************* */
   /*                                                                       */
   /*  Gives the list of edges of a mesh.                                   */
